# prfect


```
python3 prfect.py test/phiX174.gbk
```
and the output are the various heptamer slippery sequences followed by the mfe
```
3123 3224 gaaaaa -11.2
3123 3224 aaaaat -10.8
3123 3224 aaaatt -9.9
3123 3224 ggaaaa -8.6
3199 3309 ggaaaa -8.6
3199 3309 aaaatt -11.3
3199 3309 caaaaa -16.8
3199 3309 aaaaac -17.2
3890 3936 caaaaa -15.7
3890 3936 aaaaat -15.3
3890 3936 aaaatt -15.3
```
